@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.010001;
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 use Exporter 'import';
 our @EXPORT_OK = qw( print_table );
 
@@ -45,9 +45,10 @@ sub __validate_options {
         max_rows        => '[ 0-9 ]+',
         min_col_width   => '[ 0-9 ]+',
         tab_width       => '[ 0-9 ]+',
-        table_expand    => '[ 0 1 ]',
         binary_filter   => '[ 0 1 ]',
         add_header      => '[ 0 1 ]',
+        keep_header     => '[ 0 1 ]',
+        table_expand    => '[ 0 1 ]',
         choose_columns  => '[ 0 1 2 ]',
         mouse           => '[ 0 1 2 3 4 ]',
         binary_string   => '',
@@ -89,6 +90,7 @@ sub __set_defaults {
     $self->{binary_string}  //= 'BNRY';
     $self->{choose_columns} //= 0;
     $self->{add_header}     //= 0;
+    $self->{keep_header}    //= 1;
     $self->{thsd_sep} = ',';
     $self->{no_col}   = 'col';
 }
@@ -174,6 +176,7 @@ sub print_table {
         if ( $self->{add_header} ) {
             unshift @$table_ref, [ map { $_ . '_' . $self->{no_col} } 1 .. @{$table_ref->[0]} ];
         }
+        croak "Empty table without header row!" if ! @$table_ref;
         my $last_row_idx = $self->{max_rows} && $self->{max_rows} < @$table_ref ? $self->{max_rows} : $#$table_ref;
         my @copy = ();
         if ( $self->{choose_columns}  ) {
@@ -230,7 +233,9 @@ sub __inner_print_tbl {
         }
         push @$list, unicode_sprintf( $reached_limit, $len, 0 );
     }
-    my $old_row = 0;
+    my $old_row = $self->{keep_header} ? @$list : 0;
+    #my $old_row = 0;
+    #my $auto_jump = 1;
     my ( $width ) = term_size();
     while ( 1 ) {
         if ( ( term_size() )[0] != $width ) {
@@ -238,22 +243,47 @@ sub __inner_print_tbl {
             $self->__inner_print_tbl( $a_ref );
             return;
         }
+        my $prompt = $self->{keep_header} ? shift @$list : '';
+        if ( ! @$list ) {
+            push @$list, $prompt;
+            $prompt = '';
+            $old_row = 0;
+        }
         my $row = choose(
             $list,
-            { prompt => '', index => 1, default => $old_row, ll => $len, layout => 3,
+            { prompt => $prompt, index => 1, default => $old_row, ll => $len, layout => 3,
               clear_screen => 1, mouse => $self->{mouse} }
         );
+        unshift @$list, $prompt if $self->{keep_header};
         return if ! defined $row;
-        return if $row == 0;
         if ( ! $self->{table_expand} ) {
-            $old_row = 0;
+            return if $row == 0;
             next;
         }
         if ( $old_row == $row ) {
+            return if $row == 0;
             $old_row = 0;
             next;
         }
+        #if ( ! $self->{table_expand} ) {
+        #    return if $row == 0;
+        #    next;
+        #}
+        #if ( $old_row == $row && ! $self->{keep_header} ) {
+        #    return if $row == 0;
+        #    $old_row = 0;
+        #    next;
+        #}
+        #if ( $old_row == $row && ! $auto_jump ) {
+        #    return if $row == 0;
+        #    $old_row = 0;
+        #    $auto_jump = 1;
+        #    next;
+        #}
+        #$auto_jump = 0;
         $old_row = $row;
+        $row++ if $prompt;
+
         my $row_data = $self->__single_row( $a_ref, $row, $self->{longest_col_name} + 1 );
         choose(
             $row_data,
@@ -508,7 +538,7 @@ Term::TablePrint - Print a table to the terminal and browse it interactively.
 
 =head1 VERSION
 
-Version 0.010
+Version 0.011
 
 =cut
 
@@ -625,9 +655,11 @@ row of the table.
 
 =back
 
-The C<Return> key closes the table if the cursor is on the header row.
+The C<Return> key closes the table if the cursor is on the header row. If <keep_header> is enabled, the C<Return> key
+closes the table if the pointer jumped automatically to the first row else the table closes by selecting the first row
+twice in succession.
 
-If the cursor is not on the header row:
+If the cursor is not on the first row:
 
 =over
 
@@ -639,7 +671,8 @@ with the option I<table_expand> disabled the cursor jumps to the table head if C
 
 with the option I<table_expand> enabled each column of the selected row is output in its own line preceded by the
 column name if C<Return> is pressed. Another C<Return> closes this output and goes back to the table output. If a row is
-selected twice in succession, the pointer jumps to the head of the table.
+selected twice in succession, the pointer jumps to the head of the table or to the first row if I<keep_header> is
+enabled.
 
 =back
 
@@ -659,6 +692,16 @@ If I<add_header> is set to 1, C<print_table> adds a header row - the columns are
 
 Default: 0
 
+=head3 binary_filter
+
+If I<binary_filter> is set to 1, "BNRY" is printed instead of arbitrary binary data.
+
+If the data matches the repexp C</[\x00-\x08\x0B-\x0C\x0E-\x1F]/>, it is considered arbitrary binary data.
+
+Printing arbitrary binary data could break the output.
+
+Default: 0
+
 =head3 choose_columns
 
 If I<choose_columns> is set to 1, the user can choose which columns to print. The columns can be marked with the
@@ -669,24 +712,13 @@ the C<SpaceBar> and the C<Return> key) until the user confirms with the I<-ok->
 
 Default: 0
 
-=head3 tab_width
+=head3 keep_header
 
-Set the number of spaces between columns.
+If I<keep_header> is set to 1, the table header is shown on top of each page.
 
-Default: 2
+If I<keep_header> is set to 0, the table header is shown on top of the first page.
 
-=head3 min_col_width
-
-The columns with a width below or equal I<min_col_width> are only trimmed if it is still required to lower the row width
-despite all columns wider than I<min_col_width> have been trimmed to I<min_col_width>.
-
-Default: 30
-
-=head3 undef
-
-Set the string that will be shown on the screen instead of an undefined field.
-
-Default: "" (empty string)
+Default: 1;
 
 =head3 max_rows
 
@@ -699,21 +731,12 @@ If the number of table rows is equal to or higher than I<max_rows>, the last row
 
 Default: 50_000
 
-=head3 progress_bar
+=head3 min_col_width
 
-Set the progress bar threshold. If the number of fields (rows x columns) is higher than the threshold, a progress bar is
-shown while preparing the data for the output.
+The columns with a width below or equal I<min_col_width> are only trimmed if it is still required to lower the row width
+despite all columns wider than I<min_col_width> have been trimmed to I<min_col_width>.
 
-Default: 20_000
-
-=head3 table_expand
-
-If the option I<table_expand> is set to 1 and C<Return> is pressed, the selected table row is printed with each column
-in its own line.
-
-If I<table_expand> is set to 0, the cursor jumps to the to header row (if not already there) when C<Return> is pressed.
-
-Default: 1
+Default: 30
 
 =head3 mouse
 
@@ -721,15 +744,33 @@ Set the I<mouse> mode (see option C<mouse> in L<Term::Choose/OPTIONS>).
 
 Default: 0
 
-=head3 binary_filter
+=head3 progress_bar
 
-If I<binary_filter> is set to 1, "BNRY" is printed instead of arbitrary binary data.
+Set the progress bar threshold. If the number of fields (rows x columns) is higher than the threshold, a progress bar is
+shown while preparing the data for the output.
 
-If the data matches the repexp C</[\x00-\x08\x0B-\x0C\x0E-\x1F]/>, it is considered arbitrary binary data.
+Default: 20_000
 
-Printing arbitrary binary data could break the output.
+=head3 tab_width
 
-Default: 0
+Set the number of spaces between columns.
+
+Default: 2
+
+=head3 table_expand
+
+If the option I<table_expand> is set to 1 and C<Return> is pressed, the selected table row is printed with each column
+in its own line.
+
+If I<table_expand> is set to 0, the cursor jumps to the to first row (if not already there) when C<Return> is pressed.
+
+Default: 1
+
+=head3 undef
+
+Set the string that will be shown on the screen instead of an undefined field.
+
+Default: "" (empty string)
 
 =head1 ERROR HANDLING
 
